==> vue-pager-2.21.0.tgz: package/lib/pc.js <==
import PagerItem from '@opentinyvue/vue-pager-item';
import BaseSelect from '@opentinyvue/vue-base-select';
import Popover from '@opentinyvue/vue-popover';
import Loading from '@opentinyvue/vue-loading';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/pager/vue';
import { iconChevronLeft, iconChevronRight, iconTriangleDown } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/pager/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Pager",
  props: [].concat(props, ["accurateJumper", "appendToBody", "currentPage", "disabled", "hideOnSinglePage", "isBeforePageChange", "layout", "mode", "nextText", "pageCount", "pageSize", "pageSizes", "pagerCount", "popperAppendToBody", "showTotalLoading", "customTotal", "popperClass", "prevText", "total", "size", "align", "totalFixedLeft", "pageSizeText", "changeCompat"]),
  directives: {
    loading: Loading.directive
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  },
  components: {
    TinyPopover: Popover,
    TinyBaseSelect: BaseSelect,
    ChevronLeft: iconChevronLeft(),
    ChevronRight: iconChevronRight(),
    TriangleDown: iconTriangleDown(),
    Pager: PagerItem
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _vm.state.showPager ? _c("div", {
    class: ["tiny-pager tiny-pager__number", _vm.size ? "tiny-pager--" + _vm.size : "", _vm.disabled ? "is-disabled" : ""],
    style: {
      textAlign: _vm.state.align
    }
  }, [_vm._l(_vm.state.internalLayout, function(item, index) {
    return [item === "prev" ? _c("button", {
      key: "prev" + index,
      staticClass: "tiny-pager__btn-prev",
      attrs: {
        "type": "button",
        "disabled": _vm.disabled || _vm.state.internalCurrentPage <= 1
      },
      on: {
        "click": _vm.prev
      }
    }, [_vm.prevText ? _c("span", [_vm._v(_vm._s(_vm.prevText))]) : _c("chevron-left", {
      staticClass: "tiny-svg-size"
    })], 1) : item === "jumper" ? _c("div", {
      key: "jumper" + index,
      staticClass: "tiny-pager__group"
    }, [_c("div", {
      staticClass: "tiny-pager__goto"
    }, [_c("span", {
      staticClass: "tiny-pager__goto-text"
    }, [_vm._v(_vm._s(_vm.t("ui.page.jump")))]), _c("input", {
      ref: "jumperInput",
      refInFor: true,
      attrs: {
        "type": "text",
        "disabled": _vm.disabled
      },
      domProps: {
        "value": _vm.state.jumperValue
      },
      on: {
        "focus": _vm.handleJumperFocus,
        "input": _vm.handleJumperInput,
        "change": _vm.handleJumperChange
      }
    }), _vm.state.showJumperSuffix ? _c("span", {
      staticClass: "tiny-pager__goto-text tiny-pager__goto-text-sufix"
    }, [_vm._v(_vm._s(_vm.t("ui.page.pageClassifier")))]) : _vm._e()])]) : item === "current" ? _c("div", {
      key: "current" + index,
      staticClass: "tiny-pager__group tiny-unselect"
    }, [_c("ul", {
      staticClass: "tiny-pager__pages"
    }, [_c("li", {
      staticClass: "is-active"
    }, [_vm._v(_vm._s(_vm.state.internalCurrentPage))])])]) : item === "pager" ? _c("pager", {
      key: "pager" + index,
      attrs: {
        "is-before-page-change": _vm.isBeforePageChange,
        "current-page": _vm.state.internalCurrentPage,
        "page-count": _vm.state.internalPageCount,
        "pager-count": _vm.pagerCount,
        "disabled": _vm.disabled
      },
      on: {
        "change": _vm.handleCurrentChange,
        "before-page-change": _vm.beforePagerChangeHandler
      }
    }) : item === "simplest-pager" ? _c("tiny-base-select", {
      key: "simplest-pager" + index,
      style: {
        width: _vm.state.simplestPagerWidth + "px"
      },
      attrs: {
        "size": _vm.size,
        "disabled": _vm.disabled,
        "options": _vm.state.simplestPagerOption,
        "popper-class": "tiny-pager__simplest-pager-popover",
        "optimization": _vm.state.simplestPagerOption.length > 30
      },
      on: {
        "change": _vm.handleCurrentChange
      },
      model: {
        value: _vm.state.internalCurrentPage,
        callback: function callback($$v) {
          _vm.$set(_vm.state, "internalCurrentPage", $$v);
        },
        expression: "state.internalCurrentPage"
      }
    }) : item === "next" ? _c("button", {
      key: "next" + index,
      staticClass: "tiny-pager__btn-next",
      attrs: {
        "type": "button",
        "disabled": _vm.disabled || _vm.state.internalCurrentPage === _vm.state.internalPageCount || _vm.state.internalPageCount === 0
      },
      on: {
        "click": _vm.next
      }
    }, [_vm.nextText ? _c("span", [_vm._v(_vm._s(_vm.nextText))]) : _c("chevron-right", {
      staticClass: "tiny-svg-size"
    })], 1) : item === "sizes" ? _c("div", {
      key: "sizes" + index,
      staticClass: "tiny-pager__group tiny-pager__sizes"
    }, [_c("tiny-popover", {
      ref: "sizesList",
      refInFor: true,
      attrs: {
        "placement": "bottom-start",
        "append-to-body": _vm.popperAppendToBody === false ? false : _vm.appendToBody,
        "trigger": "click",
        "popper-class": "tiny-pager__selector " + (_vm.popperClass ? "" + _vm.popperClass : ""),
        "visible-arrow": false,
        "disabled": _vm.disabled
      },
      on: {
        "show": _vm.handleSizeShowPopover,
        "hide": _vm.handleSizeHidePopover
      },
      scopedSlots: _vm._u([{
        key: "reference",
        fn: function fn() {
          var _vm$state$pageSizeTex;
          return [_c("div", {
            staticClass: "tiny-pager__popover",
            on: {
              "click": _vm.clickSizes
            }
          }, [_c("div", {
            ref: "pageSize",
            refInFor: true,
            staticClass: "tiny-pager__page-size",
            class: {
              disabled: _vm.disabled
            }
          }, [_c("span", {
            staticClass: "sizes"
          }, [_vm._v(_vm._s(_vm.state.internalPageSize))]), _c("span", [_vm._v(_vm._s((_vm$state$pageSizeTex = _vm.state.pageSizeText) !== null && _vm$state$pageSizeTex !== void 0 ? _vm$state$pageSizeTex : _vm.t("ui.page.page")))]), _c("div", {
            staticClass: "tiny-pager__page-size-btn"
          }, [_c("triangle-down", {
            class: ["tiny-svg-size", _vm.state.showSizes ? "tiny-svg-size__reverse-180" : ""]
          })], 1)])])];
        },
        proxy: true
      }], null, true)
    }, [_c("div", {
      staticClass: "tiny-pager__selector-body"
    }, [_c("ul", {
      staticClass: "tiny-pager__selector-poplist"
    }, _vm._l(_vm.pageSizes, function(sizeItem, sizeIndex) {
      return _c("li", {
        key: sizeIndex,
        class: ["list-item", sizeItem === _vm.state.internalPageSize ? "is-selected select-pre" : ""],
        attrs: {
          "title": String(sizeItem)
        },
        on: {
          "click": function click($event) {
            return _vm.handleSizeChange(sizeItem);
          }
        }
      }, [_vm._v(" " + _vm._s(sizeItem) + " ")]);
    }), 0)])])], 1) : item === "slot" ? _vm._t("default") : item === "total" && typeof _vm.state.internalTotal === "number" ? _c("div", {
      key: "total" + index,
      staticClass: "tiny-pager__group",
      class: {
        "is-disabled": _vm.disabled,
        "tiny-pager__loading": _vm.showTotalLoading,
        "tiny-pager__pull-left": _vm.state.totalFixedLeft
      }
    }, [_c("div", {
      class: ["tiny-pager__total", _vm.size ? "tiny-pager--" + _vm.size : ""]
    }, [_vm.showTotalLoading ? [_c("div", {
      directives: [{
        name: "loading",
        rawName: "v-loading",
        value: _vm.showTotalLoading,
        expression: "showTotalLoading"
      }],
      staticClass: "tiny-pager__total-loading"
    }), _c("span", {
      staticClass: "tiny-pager__loading-text"
    }, [_vm._v(_vm._s(_vm.t("ui.page.loadingTotals")))])] : _vm.state.totalI18n === "total" ? [_c("span", [_vm._v(_vm._s(_vm.t("ui.page.total")))]), _c("span", {
      staticClass: "tiny-pager__total-allpage"
    }, [_vm._v(" " + _vm._s(_vm.customTotal ? _vm.state.totalText : _vm.state.internalTotal) + " ")]), _c("span", [_vm._v(_vm._s(_vm.t("ui.page.item")))])] : [_c("span", [_vm._v(_vm._s(_vm.t("ui.page.totals")))]), _c("span", {
      class: {
        "tiny-pager__total-num": !_vm.customTotal
      }
    }, [_vm._v(" " + _vm._s(_vm.customTotal ? _vm.state.totalText : _vm.state.internalTotal) + " ")])]], 2)]) : _vm._e()];
  })], 2) : _vm._e();
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };

==> vue-pager-2.24.0.tgz: package/lib/pc.js <==
import PagerItem from '@opentinyvue/vue-pager-item';
import BaseSelect from '@opentinyvue/vue-base-select';
import Popover from '@opentinyvue/vue-popover';
import Loading from '@opentinyvue/vue-loading';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/pager/vue';
import { iconChevronLeft, iconChevronRight, iconTriangleDown } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/pager/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Pager",
  props: [].concat(props, ["accurateJumper", "appendToBody", "currentPage", "disabled", "hideOnSinglePage", "isBeforePageChange", "layout", "mode", "nextText", "pageCount", "pageSize", "pageSizes", "pagerCount", "popperAppendToBody", "showTotalLoading", "customTotal", "popperClass", "prevText", "total", "size", "align", "totalFixedLeft", "pageSizeText", "changeCompat"]),
  directives: {
    loading: Loading.directive
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  },
  components: {
    TinyPopover: Popover,
    TinyBaseSelect: BaseSelect,
    ChevronLeft: iconChevronLeft(),
    ChevronRight: iconChevronRight(),
    TriangleDown: iconTriangleDown(),
    Pager: PagerItem
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _vm.state.showPager ? _c("div", {
    class: ["tiny-pager tiny-pager__number", _vm.size ? "tiny-pager--" + _vm.size : "", _vm.disabled ? "is-disabled" : ""],
    style: {
      textAlign: _vm.state.align
    }
  }, [_vm._l(_vm.state.internalLayout, function(item, index) {
    return [item === "prev" ? _c("button", {
      key: "prev" + index,
      staticClass: "tiny-pager__btn-prev",
      attrs: {
        "type": "button",
        "disabled": _vm.disabled || _vm.state.internalCurrentPage <= 1
      },
      on: {
        "click": _vm.prev
      }
    }, [_vm.prevText ? _c("span", [_vm._v(_vm._s(_vm.prevText))]) : _c("chevron-left", {
      staticClass: "tiny-svg-size"
    })], 1) : item === "jumper" ? _c("div", {
      key: "jumper" + index,
      staticClass: "tiny-pager__group"
    }, [_c("div", {
      staticClass: "tiny-pager__goto"
    }, [_c("span", {
      staticClass: "tiny-pager__goto-text"
    }, [_vm._v(_vm._s(_vm.t("ui.page.jump")))]), _c("input", {
      ref: "jumperInput",
      refInFor: true,
      attrs: {
        "type": "text",
        "disabled": _vm.disabled
      },
      domProps: {
        "value": _vm.state.jumperValue
      },
      on: {
        "focus": _vm.handleJumperFocus,
        "input": _vm.handleJumperInput,
        "change": _vm.handleJumperChange
      }
    }), _vm.state.showJumperSuffix ? _c("span", {
      staticClass: "tiny-pager__goto-text tiny-pager__goto-text-sufix"
    }, [_vm._v(_vm._s(_vm.t("ui.page.pageClassifier")))]) : _vm._e()])]) : item === "current" ? _c("div", {
      key: "current" + index,
      staticClass: "tiny-pager__group tiny-unselect"
    }, [_c("ul", {
      staticClass: "tiny-pager__pages"
    }, [_c("li", {
      staticClass: "is-active"
    }, [_vm._v(_vm._s(_vm.state.internalCurrentPage))])])]) : item === "pager" ? _c("pager", {
      key: "pager" + index,
      attrs: {
        "is-before-page-change": _vm.isBeforePageChange,
        "current-page": _vm.state.internalCurrentPage,
        "page-count": _vm.state.internalPageCount,
        "pager-count": _vm.pagerCount,
        "disabled": _vm.disabled
      },
      on: {
        "change": _vm.handleCurrentChange,
        "before-page-change": _vm.beforePagerChangeHandler
      }
    }) : item === "simplest-pager" ? _c("tiny-base-select", {
      key: "simplest-pager" + index,
      style: {
        width: _vm.state.simplestPagerWidth + "px"
      },
      attrs: {
        "size": _vm.size,
        "disabled": _vm.disabled,
        "options": _vm.state.simplestPagerOption,
        "popper-class": "tiny-pager__simplest-pager-popover",
        "optimization": _vm.state.simplestPagerOption.length > 30
      },
      on: {
        "change": _vm.handleCurrentChange
      },
      model: {
        value: _vm.state.internalCurrentPage,
        callback: function callback($$v) {
          _vm.$set(_vm.state, "internalCurrentPage", $$v);
        },
        expression: "state.internalCurrentPage"
      }
    }) : item === "next" ? _c("button", {
      key: "next" + index,
      staticClass: "tiny-pager__btn-next",
      attrs: {
        "type": "button",
        "disabled": _vm.disabled || _vm.state.internalCurrentPage === _vm.state.internalPageCount || _vm.state.internalPageCount === 0
      },
      on: {
        "click": _vm.next
      }
    }, [_vm.nextText ? _c("span", [_vm._v(_vm._s(_vm.nextText))]) : _c("chevron-right", {
      staticClass: "tiny-svg-size"
    })], 1) : item === "sizes" ? _c("div", {
      key: "sizes" + index,
      staticClass: "tiny-pager__group tiny-pager__sizes"
    }, [_c("tiny-popover", {
      ref: "sizesList",
      refInFor: true,
      attrs: {
        "placement": "bottom-start",
        "append-to-body": _vm.popperAppendToBody === false ? false : _vm.appendToBody,
        "trigger": "click",
        "popper-class": "tiny-pager__selector " + (_vm.popperClass ? "" + _vm.popperClass : ""),
        "visible-arrow": false,
        "disabled": _vm.disabled
      },
      on: {
        "show": _vm.handleSizeShowPopover,
        "hide": _vm.handleSizeHidePopover
      },
      scopedSlots: _vm._u([{
        key: "reference",
        fn: function fn() {
          var _vm$state$pageSizeTex;
          return [_c("div", {
            staticClass: "tiny-pager__popover",
            on: {
              "click": _vm.clickSizes
            }
          }, [_c("div", {
            ref: "pageSize",
            refInFor: true,
            staticClass: "tiny-pager__page-size",
            class: {
              disabled: _vm.disabled
            }
          }, [_c("span", {
            staticClass: "sizes"
          }, [_vm._v(_vm._s(_vm.state.internalPageSize))]), _c("span", [_vm._v(_vm._s((_vm$state$pageSizeTex = _vm.state.pageSizeText) !== null && _vm$state$pageSizeTex !== void 0 ? _vm$state$pageSizeTex : _vm.t("ui.page.page")))]), _c("div", {
            staticClass: "tiny-pager__page-size-btn"
          }, [_c("triangle-down", {
            class: ["tiny-svg-size", _vm.state.showSizes ? "tiny-svg-size__reverse-180" : ""]
          })], 1)])])];
        },
        proxy: true
      }], null, true)
    }, [_c("div", {
      staticClass: "tiny-pager__selector-body"
    }, [_c("ul", {
      staticClass: "tiny-pager__selector-poplist"
    }, _vm._l(_vm.pageSizes, function(sizeItem, sizeIndex) {
      return _c("li", {
        key: sizeIndex,
        class: ["list-item", sizeItem === _vm.state.internalPageSize ? "is-selected select-pre" : ""],
        attrs: {
          "title": String(sizeItem)
        },
        on: {
          "click": function click($event) {
            return _vm.handleSizeChange(sizeItem);
          }
        }
      }, [_vm._v(" " + _vm._s(sizeItem) + " ")]);
    }), 0)])])], 1) : item === "slot" ? _vm._t("default") : item === "total" && typeof _vm.state.internalTotal === "number" ? _c("div", {
      key: "total" + index,
      staticClass: "tiny-pager__group",
      class: {
        "is-disabled": _vm.disabled,
        "tiny-pager__loading": _vm.showTotalLoading,
        "tiny-pager__pull-left": _vm.state.totalFixedLeft
      }
    }, [_c("div", {
      class: ["tiny-pager__total", _vm.size ? "tiny-pager--" + _vm.size : ""]
    }, [_vm.showTotalLoading ? [_c("div", {
      directives: [{
        name: "loading",
        rawName: "v-loading",
        value: _vm.showTotalLoading,
        expression: "showTotalLoading"
      }],
      staticClass: "tiny-pager__total-loading"
    }), _c("span", {
      staticClass: "tiny-pager__loading-text"
    }, [_vm._v(_vm._s(_vm.t("ui.page.loadingTotals")))])] : _vm.state.totalI18n === "total" ? [_c("span", [_vm._v(_vm._s(_vm.t("ui.page.total")))]), _c("span", {
      staticClass: "tiny-pager__total-allpage"
    }, [_vm._v(" " + _vm._s(_vm.customTotal ? _vm.state.totalText : _vm.state.internalTotal) + " ")]), _c("span", [_vm._v(_vm._s(_vm.t("ui.page.item")))])] : [_c("span", [_vm._v(_vm._s(_vm.t("ui.page.totals") + " "))]), _c("span", {
      class: {
        "tiny-pager__total-num": !_vm.customTotal
      }
    }, [_vm._v(" " + _vm._s(_vm.customTotal ? _vm.state.totalText : _vm.state.internalTotal) + " ")])]], 2)]) : _vm._e()];
  })], 2) : _vm._e();
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
